# Python CGI

<badges>[![version](https://img.shields.io/pypi/v/pythoncgi.svg)](https://pypi.org/project/pythoncgi/)
[![license](https://img.shields.io/pypi/l/pythoncgi.svg)](https://pypi.org/project/pythoncgi/)
[![pyversions](https://img.shields.io/pypi/pyversions/pythoncgi.svg)](https://pypi.org/project/pythoncgi/)  
[![donate](https://img.shields.io/badge/Donate-Paypal-0070ba.svg)](https://paypal.me/foxe6)
[![powered](https://img.shields.io/badge/Powered%20by-UTF8-red.svg)](https://paypal.me/foxe6)
[![made](https://img.shields.io/badge/Made%20with-PyCharm-red.svg)](https://paypal.me/foxe6)
</badges>

<i>Extremely simple Python CGI framework for Apache 2.</i>

# Hierarchy

```
pythoncgi
|---- _SERVER
|---- _GET
|---- _POST
|---- _SESSION
|---- _COOKIE
|---- _HEADERS
|---- set_status()
|---- set_header()
|---- execute()
|---- print()
|---- main()
|---- log_construct()
'---- log()
```

# Example

See [pythoncgi/example](pythoncgi/example).
